/*
 * This file is part of smolbote. It's copyrighted by the contributors recorded
 * in the version control history of the file, available from its original
 * location: https://neueland.iserlohn-fortress.net/gitea/aqua/smolbote
 *
 * SPDX-License-Identifier: GPL-3.0
 */

#include "aboutdialog.h"
#include "ui_aboutdialog.h"
#include <version.h>

// compiler
// clang also defines __GNUC__, so we need to check for clang first
#if defined(__clang__)
#define compiler "Clang " __clang_version__
#elif defined(__GNUC__)
#define compiler "GCC " __VERSION__
#elif defined(_MSC_VER)
#define compiler "MSVC"
#else
#define compiler "unknown compiler"
#endif

AboutDialog::AboutDialog(QWidget *parent)
    : QDialog(parent)
    , ui(new Ui::AboutDialog)
{
    setAttribute(Qt::WA_DeleteOnClose, true);
    ui->setupUi(this);

    ui->icon->setPixmap(qApp->windowIcon().pixmap(72, 72));

    ui->aboutLabel->setText(tr("<h2>smolbote %1</h2>"
                               "<p><i>yet another no-frills browser</i></p>"
                               "<p>This program is free software, see <i>License</i> for more information.</p>")
                                .arg(qApp->applicationVersion()));

    ui->licenseLabel->setText(tr("<p>Copyright 2017 - 2019 aqua</p>"
                                 "<p>This program is free software, and you are welcome to use it under the conditions set by the GNU GPLv3.<br>"
                                 "This is a short summary: <ul>"
                                 "<li> the freedom to use the software for any purpose,</li>"
                                 "<li> the freedom to change the software to suit your needs,</li>"
                                 "<li> the freedom to share the software with anyone,</li>"
                                 "<li> the freedom to share the changes you make, and</li>"
                                 "<li> the responsibility to grant the same freedoms when sharing the software.</li>"
                                 "</ul>"
                                 "<p>This program is distributed in the hope that it will be useful, but without any warranty.</p>"
                                 "<p>You can read the full terms of the license on <a href='https://www.gnu.org/licenses/gpl-3.0.en.html'>the GNU website</a>.</p>"));

    ui->detailsLabel->setText(tr("<p>Version " poi_Version "</p>"
                                 "<p>Compiled with " compiler "</p>"
                                 "<p>Libraries: <ul>"
                                 "<li><a href='https://www.qt.io/'>Qt5</a> " QT_VERSION_STR "</li>"
                                 "<li>spdlog</li>"
                                 "<li><a href='https://github.com/Taywee/args'>args.hxx</a></li>"
                                 "<li><a href='https://github.com/itay-grudev/SingleApplication'>SingleApplication</a></li>"
#ifdef CONFIG_USEPLASMA
                                 "<li><a href='https://community.kde.org/Frameworks'>KDE Frameworks</a></li>"
#endif
#ifdef CONFIG_USEBREAKPAD
                                 "<li><a href='https://chromium.googlesource.com/breakpad/breakpad'>Breakpad</a></li>"
#endif
                                 "</ul></p>"));

}

AboutDialog::~AboutDialog()
{
    delete ui;
}
