/*
 * This file is part of smolbote. It's copyrighted by the contributors recorded
 * in the version control history of the file, available from its original
 * location: https://neueland.iserlohn-fortress.net/gitea/aqua/smolbote
 *
 * SPDX-License-Identifier: GPL-3.0
 */

#ifndef SMOLBOTE_WEBVIEW_H
#define SMOLBOTE_WEBVIEW_H

#include "webpage.h"
#include <QWebEngineView>
#include <session.hpp>

class WebProfile;
class SubWindow;
class WebViewContextMenu;
class WebView final : public QWebEngineView
{
    friend class WebViewContextMenu;

    Q_OBJECT

    explicit WebView(QWidget *parent = nullptr);

public:
    explicit WebView(WebProfile *profile = nullptr, QWidget *parent = nullptr);
    explicit WebView(const Session::WebView &data, QWidget *parent = nullptr);
    ~WebView() = default;

    [[nodiscard]] WebProfile *profile() const
    {
        return m_profile;
    }
    void setProfile(WebProfile *profile);

    [[nodiscard]] Session::WebView serialize() const;

    bool isLoaded() const;

public slots:
    void search(const QString &term);

signals:
    void newBookmark(const QString &title, const QUrl &url);

protected:
    WebView *createWindow(QWebEnginePage::WebWindowType type) override;
    void contextMenuEvent(QContextMenuEvent *event) override;

private:
    SubWindow *m_parentWindow = nullptr;
    WebProfile *m_profile = nullptr;

    bool m_loaded = false;
};

#endif // SMOLBOTE_WEBVIEW_H
